@@ -8,7 +8,7 @@ brief_entries <- function(data, what, when, with, .protect = TRUE) {
     with = enquo(with) %missing% NA_character_
   )
 
-  out <- dplyr::as_tibble(map(edu_exprs, rlang::eval_tidy, data = data))
+  out <- dplyr::as_tibble(map(edu_exprs, eval_tidy, data = data))
   structure(out,
     preserve = names(edu_exprs),
     protect = .protect,
@@ -16,6 +16,13 @@ brief_entries <- function(data, what, when, with, .protect = TRUE) {
   )
 }
 
+#' @importFrom tibble tbl_sum
+#' @export
+tbl_sum.vitae_brief <- function(x) {
+  x <- NextMethod()
+  c(x, "vitae type" = "brief entries")
+}
+
 #' @importFrom knitr knit_print
 #' @export
 knit_print.vitae_brief <- function(x, options) {
